ChangeLog
=========

0.0.2 (2019-09-10)
------------------

Added scan modes + publish examples through the examples module.

0.0.1 (2019-09-09)
------------------

* Essentially working for basic applications

